==> aws-android-sdk-sns-2.6.2-sources.jar: com/amazonaws/services/sns/model/transform/SubscribeRequestMarshaller.java <==
/*
 * Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.sns.model.transform;

import com.amazonaws.AmazonClientException;
import com.amazonaws.Request;
import com.amazonaws.DefaultRequest;
import com.amazonaws.services.sns.model.*;
import com.amazonaws.transform.Marshaller;
import com.amazonaws.util.StringUtils;

/**
 * StAX request marshaller for SubscribeRequest
 */
public class SubscribeRequestMarshaller implements
        Marshaller<Request<SubscribeRequest>, SubscribeRequest> {

    public Request<SubscribeRequest> marshall(SubscribeRequest subscribeRequest) {
        if (subscribeRequest == null) {
            throw new AmazonClientException("Invalid argument passed to marshall(SubscribeRequest)");
        }

        Request<SubscribeRequest> request = new DefaultRequest<SubscribeRequest>(subscribeRequest,
                "AmazonSNS");
        request.addParameter("Action", "Subscribe");
        request.addParameter("Version", "2010-03-31");

        String prefix;
        if (subscribeRequest.getTopicArn() != null) {
            prefix = "TopicArn";
            String topicArn = subscribeRequest.getTopicArn();
            request.addParameter(prefix, StringUtils.fromString(topicArn));
        }
        if (subscribeRequest.getProtocol() != null) {
            prefix = "Protocol";
            String protocol = subscribeRequest.getProtocol();
            request.addParameter(prefix, StringUtils.fromString(protocol));
        }
        if (subscribeRequest.getEndpoint() != null) {
            prefix = "Endpoint";
            String endpoint = subscribeRequest.getEndpoint();
            request.addParameter(prefix, StringUtils.fromString(endpoint));
        }

        return request;
    }
}

==> aws-android-sdk-sns-2.22.0-sources.jar: com/amazonaws/services/sns/model/transform/SubscribeRequestMarshaller.java <==
/*
 * Copyright 2010-2021 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.sns.model.transform;

import com.amazonaws.AmazonClientException;
import com.amazonaws.Request;
import com.amazonaws.DefaultRequest;
import com.amazonaws.services.sns.model.*;
import com.amazonaws.transform.Marshaller;
import com.amazonaws.util.StringUtils;

/**
 * StAX request marshaller for SubscribeRequest
 */
public class SubscribeRequestMarshaller implements
        Marshaller<Request<SubscribeRequest>, SubscribeRequest> {

    public Request<SubscribeRequest> marshall(SubscribeRequest subscribeRequest) {
        if (subscribeRequest == null) {
            throw new AmazonClientException("Invalid argument passed to marshall(SubscribeRequest)");
        }

        Request<SubscribeRequest> request = new DefaultRequest<SubscribeRequest>(subscribeRequest,
                "AmazonSNS");
        request.addParameter("Action", "Subscribe");
        request.addParameter("Version", "2010-03-31");

        String prefix;
        if (subscribeRequest.getTopicArn() != null) {
            prefix = "TopicArn";
            String topicArn = subscribeRequest.getTopicArn();
            request.addParameter(prefix, StringUtils.fromString(topicArn));
        }
        if (subscribeRequest.getProtocol() != null) {
            prefix = "Protocol";
            String protocol = subscribeRequest.getProtocol();
            request.addParameter(prefix, StringUtils.fromString(protocol));
        }
        if (subscribeRequest.getEndpoint() != null) {
            prefix = "Endpoint";
            String endpoint = subscribeRequest.getEndpoint();
            request.addParameter(prefix, StringUtils.fromString(endpoint));
        }
        if (subscribeRequest.getAttributes() != null) {
            prefix = "Attributes";
            java.util.Map<String, String> attributes = subscribeRequest.getAttributes();
            int attributesIndex = 1;
            String attributesPrefix = prefix + ".entry.";
            for (java.util.Map.Entry<String, String> attributesEntry : attributes.entrySet()) {
                prefix = attributesPrefix + attributesIndex;
                if (attributesEntry.getKey() != null) {
                    request.addParameter(prefix + ".key",
                            StringUtils.fromString(attributesEntry.getKey()));
                }
                prefix += ".value";
                if (attributesEntry.getValue() != null) {
                    String attributesValue = attributesEntry.getValue();
                    request.addParameter(prefix, StringUtils.fromString(attributesValue));
                }
                attributesIndex++;
            }
            prefix = attributesPrefix;
        }
        if (subscribeRequest.getReturnSubscriptionArn() != null) {
            prefix = "ReturnSubscriptionArn";
            Boolean returnSubscriptionArn = subscribeRequest.getReturnSubscriptionArn();
            request.addParameter(prefix, StringUtils.fromBoolean(returnSubscriptionArn));
        }

        return request;
    }
}
